# pycowsay

A talking cow! A rich version of [pycowsay](https://github.com/cs01/pycowsay).

## Run

Use [pipx](https://pypa.github.io/pipx/) to run without permanently installing

```bash
pipx run pycowsay-rich mooo
```

## Install

Use [pipx](https://pypa.github.io/pipx/) to install to isolated enviroment.

```bash
pipx install pycowsay-rich
```

Use pip to install to python enviroment.

```bash
pip install pycowsay-rich
```

